@@ -60,6 +60,7 @@ class ResourceRegistry(object):
 
 class QueryBuilder(object):
     """
+    1. Simple example
     ::
 
         query_builder = QueryBuilder({
@@ -68,6 +69,24 @@ class QueryBuilder(object):
             'comments': Comment
         })
 
+    2. Example using type formatters::
+
+
+        def isoformat(date):
+            return sa.func.to_char(
+                date,
+                sa.text('\'YYYY-MM-DD"T"HH24:MI:SS.US"Z"\'')
+            ).label(date.name)
+
+        query_builder = QueryBuilder(
+            {
+                'articles': Article,
+                'users': User,
+                'comments': Comment
+            },
+            type_formatters={sa.DateTime: isoformat}
+        )
+
 
     :param model_mapping:
         A mapping with keys representing JSON API resource identifier type
@@ -80,14 +99,25 @@ class QueryBuilder(object):
     :param base_url:
         Base url to be used for building JSON API compatible links objects. By
         default this is `None` indicating that no link objects will be built.
+    :param type_formatters:
+        A dictionary of type formatters
+    :param sort_included:
+        Whether or not to sort included objects by type and id.
     """
-    def __init__(self, model_mapping, base_url=None, type_formatters=None):
+    def __init__(
+        self,
+        model_mapping,
+        base_url=None,
+        type_formatters=None,
+        sort_included=True
+    ):
         self.validate_model_mapping(model_mapping)
         self.resource_registry = ResourceRegistry(model_mapping)
         self.base_url = base_url
         self.type_formatters = (
             {} if type_formatters is None else type_formatters
         )
+        self.sort_included = sort_included
 
     def validate_model_mapping(self, model_mapping):
         for model in model_mapping.values():
@@ -201,7 +231,22 @@ class QueryBuilder(object):
         from_obj = kwargs.pop('from_obj', None)
         if from_obj is None:
             from_obj = sa.orm.query.Query(model)
-        from_obj = from_obj.filter(prop._with_parent(obj))
+
+        # SQLAlchemy Query.with_parent throws warning if the primary object
+        # foreign key is NULL. Thus we need this ugly magic to return empty
+        # data in that scenario.
+        if (
+            prop.direction.name == 'MANYTOONE' and
+            not prop.secondary and
+            getattr(obj, prop.local_remote_pairs[0][0].key) is None
+        ):
+            expr = sa.cast({'data': None}, JSONB)
+            if kwargs.get('as_text'):
+                expr = sa.cast(expr, sa.Text)
+            return sa.select([expr])
+
+        from_obj = from_obj.with_parent(obj, prop)
+
         if prop.order_by:
             from_obj = from_obj.order_by(*prop.order_by)
 
@@ -267,7 +312,18 @@ class QueryBuilder(object):
         if from_obj is None:
             from_obj = sa.orm.query.Query(model)
 
-        from_obj = from_obj.subquery()
+        if kwargs.get('sort') is not None:
+            from_obj = apply_sort(
+                from_obj.statement,
+                from_obj,
+                kwargs.get('sort')
+            )
+        if kwargs.get('limit') is not None:
+            from_obj = from_obj.limit(kwargs.get('limit'))
+        if kwargs.get('offset') is not None:
+            from_obj = from_obj.offset(kwargs.get('offset'))
+
+        from_obj = from_obj.cte('main_query')
 
         return SelectExpression(self, model, from_obj).build_select(**kwargs)
 
@@ -404,17 +460,11 @@ class SelectExpression(Expression):
         from_args = [data_query.as_scalar().label('data')]
 
         if params.include:
-            selectable = get_selectable(self.from_obj).original
-            if params.sort is not None:
-                selectable = apply_sort(selectable, selectable, params.sort)
-            if params.limit is not None:
-                selectable = selectable.limit(params.limit)
-            if params.offset is not None:
-                selectable = selectable.offset(params.offset)
+            selectable = self.from_obj
             include_expr = IncludeExpression(
                 self.query_builder,
                 self.model,
-                selectable.alias()
+                selectable
             )
             included_query = include_expr.build_included(params)
             from_args.append(included_query.as_scalar().label('included'))
@@ -717,12 +767,6 @@ class DataExpression(Expression):
     def build_data(self, params, ids_only=False):
         expr = self.build_data_expr(params, ids_only=ids_only)
         query = sa.select([expr], from_obj=self.from_obj)
-        if params.sort is not None:
-            query = apply_sort(self.from_obj, query, params.sort)
-        if params.limit is not None:
-            query = query.limit(params.limit)
-        if params.offset is not None:
-            query = query.offset(params.offset)
         return query
 
     def build_data_array(self, params, ids_only=False):
@@ -745,13 +789,16 @@ class IncludeExpression(Expression):
         ]
 
         union_select = union(*selects).alias()
-        return sa.select(
+        query = sa.select(
             [union_select.c.included.label('included')],
             from_obj=union_select
-        ).order_by(
-            union_select.c.included[s('type')],
-            union_select.c.included[s('id')]
         )
+        if self.query_builder.sort_included:
+            query = query.order_by(
+                union_select.c.included[s('type')],
+                union_select.c.included[s('id')]
+            )
+        return query
 
     def build_included(self, params):
         included_union = self.build_included_union(params).alias()
@@ -797,7 +844,7 @@ class IncludeExpression(Expression):
             expr,
             path,
             alias,
-            get_selectable(self.from_obj),
+            self.from_obj,
             correlate=False
         ).distinct()
         if cls is self.model:
